@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -34,7 +34,7 @@ void LineEditWithAutocorrectionTest::shouldNotAutocorrectWhenDisabled()
     entries.insert(originalWord, replaceWord);
     lineedit.autocorrection()->setAutocorrectEntries(entries);
     lineedit.show();
-    QTest::qWaitForWindowExposed(&lineedit);
+    QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, originalWord);
     QTest::keyClick(&lineedit, ' ');
     QCOMPARE(lineedit.toPlainText(), QString(originalWord + QLatin1Char(' ')));
@@ -51,7 +51,7 @@ void LineEditWithAutocorrectionTest::shouldReplaceWordWhenExactText()
     lineedit.autocorrection()->setEnabledAutoCorrection(true);
     lineedit.autocorrection()->setAdvancedAutocorrect(true);
     lineedit.show();
-    QTest::qWaitForWindowExposed(&lineedit);
+    QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, originalWord);
     QTest::keyClick(&lineedit, ' ');
     QCOMPARE(lineedit.toPlainText(), QString(replaceWord + QLatin1Char(' ')));
@@ -69,7 +69,7 @@ void LineEditWithAutocorrectionTest::shouldNotReplaceWordWhenInexactText()
     lineedit.autocorrection()->setAdvancedAutocorrect(true);
     lineedit.show();
     const QString nonExactText = QStringLiteral("BLIBLI");
-    QTest::qWaitForWindowExposed(&lineedit);
+    QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, nonExactText);
     QTest::keyClick(&lineedit, ' ');
     QCOMPARE(lineedit.toPlainText(), QString(nonExactText + QLatin1Char(' ')));
@@ -82,7 +82,7 @@ void LineEditWithAutocorrectionTest::shouldNotAddTwoSpace()
     lineedit.autocorrection()->setSingleSpaces(true);
     lineedit.autocorrection()->setEnabledAutoCorrection(true);
     lineedit.show();
-    QTest::qWaitForWindowExposed(&lineedit);
+    QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, originalWord);
     QTest::keyClick(&lineedit, ' ');
     QCOMPARE(lineedit.toPlainText(), originalWord);
