@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,17 +19,17 @@
 #include "customtools/customtoolswidgetng.h"
 #include <QStackedWidget>
 #include <QTest>
+#include <QStandardPaths>
 #include <KActionCollection>
 
 CustomToolsWidgetNgTest::CustomToolsWidgetNgTest(QObject *parent)
     : QObject(parent)
 {
-
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 CustomToolsWidgetNgTest::~CustomToolsWidgetNgTest()
 {
-
 }
 
 void CustomToolsWidgetNgTest::shouldHaveDefaultValue()
