@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,8 +22,7 @@
 #include "pimcommon_private_export.h"
 class QPushButton;
 class QCheckBox;
-namespace PimCommon
-{
+namespace PimCommon {
 class LogActivitiesWidget;
 class PIMCOMMON_TESTS_EXPORT LogActivitiesDialog : public QDialog
 {
@@ -46,9 +45,10 @@ private:
     void slotLogEntryAdded(const QString &entry);
     void slotEnableLogActivities(bool state);
 
-    LogActivitiesWidget *mLogWidget;
-    QPushButton *mClearButton;
-    QCheckBox *mEnableLogActivities;
+    LogActivitiesWidget *mLogWidget = nullptr;
+    QPushButton *mClearButton = nullptr;
+    QCheckBox *mEnableLogActivities = nullptr;
+    QPushButton *mSaveButton = nullptr;
 };
 }
 
