@@ -33,10 +33,10 @@ public:
     ~TemplateEditDialog();
 
     void setTemplateName(const QString &name);
-    QString templateName() const;
+    Q_REQUIRED_RESULT QString templateName() const;
 
     void setScript(const QString &);
-    QString script() const;
+    Q_REQUIRED_RESULT QString script() const;
 
 private:
     void slotTemplateChanged();
