@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,12 +15,11 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef TEST_CUSTOMTOOLWIDGETTESTNG_GUI_H
-#define TEST_CUSTOMTOOLWIDGETTESTNG_GUI_H
+#ifndef TEST_CUSTOMTOOLSWIDGETNG_GUI_H
+#define TEST_CUSTOMTOOLSWIDGETNG_GUI_H
 
 #include <QWidget>
-namespace PimCommon
-{
+namespace PimCommon {
 class CustomToolsWidgetNg;
 }
 
